==> dde-introduction_5.6.38.orig.tar.xz: dde-introduction-5.6.38/translations/dde-introduction_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>社区</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>反馈</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>鸣谢</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>请选择桌面样式</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>您可以在任务栏右键菜单—“模式”中进行调节</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>请选择运行模式</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>您可以在控制中心个性化模块—开启或关闭窗口特效</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>请选择图标主题</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>您可以在控制中心个性化模块—图标主题中进行调节</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>介绍</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>欢迎使用</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>桌面样式</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>请选择桌面样式</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>您可以在任务栏右键菜单—“模式”中进行调节</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>运行模式</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>请选择运行模式</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>如果您的电脑配置不高，推荐您选择普通模式</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>请选择图标主题</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>您可以在控制中心个性化模块—图标主题中进行调节</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>欢迎</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>普通模式</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>特效模式</translation>
    </message>
</context>
</TS>

==> dde-introduction_7.0.4.tar.xz: dde-introduction-7.0.4/translations/dde-introduction_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>社区</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>反馈</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>鸣谢</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Align left</source>
        <translation>靠左</translation>
    </message>
    <message>
        <source>Align center</source>
        <translation>居中</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>请选择运行模式</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>您可以在控制中心个性化模块—开启或关闭窗口特效</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>请选择图标主题</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>您可以在控制中心个性化模块—图标主题中进行调节</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>请选择桌面样式</translation>
    </message>
    <message>
        <source>You can switch alignment by right clicking on the dock</source>
        <translation>您可以在任务栏右键菜单-“应用布局”中进行调节</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>介绍</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>欢迎使用</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>桌面样式</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>运行模式</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>请选择运行模式</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>如果您的电脑配置不高，推荐您选择普通模式</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>请选择图标主题</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>您可以在控制中心个性化模块—图标主题中进行调节</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>请选择桌面样式</translation>
    </message>
    <message>
        <source>You can switch alignment by right clicking on the dock</source>
        <translation>您可以在任务栏右键菜单-“应用布局”中进行调节</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>欢迎</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>普通模式</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>特效模式</translation>
    </message>
</context>
</TS>
